@@ -1,35 +1,10 @@
 # Copyright (c) Microsoft Corporation.
 # Licensed under the MIT License
 from enum import Enum, IntEnum
-from typing import List
+from typing import List, Optional
 
-from .exceptions import KustoDuplicateMappingReferenceError, KustoMappingAndMappingReferenceError
-
-
-class DataFormat(Enum):
-    """All data formats supported by Kusto."""
-
-    CSV = "csv"
-    TSV = "tsv"
-    SCSV = "scsv"
-    SOHSV = "sohsv"
-    PSV = "psv"
-    TXT = "txt"
-    JSON = "json"
-    SINGLEJSON = "singlejson"
-    AVRO = "avro"
-    PARQUET = "parquet"
-    MULTIJSON = "multijson"
-    ORC = "orc"
-    TSVE = "tsve"
-
-
-class IngestionMappingType(Enum):
-    CSV = "Csv"
-    JSON = "Json"
-    AVRO = "Avro"
-    PARQUET = "Parquet"
-    ORC = "Orc"
+from azure.kusto.data.data_format import DataFormat, IngestionMappingKind
+from .exceptions import KustoDuplicateMappingError, KustoMissingMappingError, KustoMappingError
 
 
 class ValidationOptions(IntEnum):
@@ -105,7 +80,7 @@ class ColumnMapping:
     def __init__(
         self,
         column_name: str,
-        column_type,
+        column_type: str,
         path: str = None,
         transform: TransformationMethod = TransformationMethod.NONE,
         ordinal: int = None,
@@ -132,6 +107,22 @@ class ColumnMapping:
         if storage_data_type:
             self.properties[self.STORAGE_DATA_TYPE] = storage_data_type
 
+    def is_valid(self, kind: IngestionMappingKind) -> bool:
+        if not self.column:
+            return False
+
+        if kind in (IngestionMappingKind.JSON, IngestionMappingKind.PARQUET, IngestionMappingKind.ORC, IngestionMappingKind.W3CLOGFILE):
+            return (
+                bool(self.properties.get(self.PATH))
+                or self.properties.get(self.TRANSFORMATION_METHOD) == TransformationMethod.SOURCE_LINE_NUMBER.value
+                or self.properties.get(self.TRANSFORMATION_METHOD) == TransformationMethod.SOURCE_LOCATION.value
+            )
+
+        if kind in (IngestionMappingKind.AVRO, IngestionMappingKind.APACHEAVRO):
+            return bool(self.properties.get(self.COLUMNS))
+
+        return True
+
 
 class IngestionProperties:
     """
@@ -144,55 +135,59 @@ class IngestionProperties:
         database: str,
         table: str,
         data_format: DataFormat = DataFormat.CSV,
-        ingestion_mapping: List[ColumnMapping] = None,
-        ingestion_mapping_type: IngestionMappingType = None,
-        ingestion_mapping_reference: str = None,
-        ingest_if_not_exists: List[str] = None,
-        ingest_by_tags: List[str] = None,
-        drop_by_tags: List[str] = None,
-        additional_tags: List[str] = None,
+        column_mappings: Optional[List[ColumnMapping]] = None,
+        ingestion_mapping_kind: Optional[IngestionMappingKind] = None,
+        ingestion_mapping_reference: Optional[str] = None,
+        ingest_if_not_exists: Optional[List[str]] = None,
+        ingest_by_tags: Optional[List[str]] = None,
+        drop_by_tags: Optional[List[str]] = None,
+        additional_tags: Optional[List[str]] = None,
         flush_immediately: bool = False,
         report_level: ReportLevel = ReportLevel.DoNotReport,
         report_method: ReportMethod = ReportMethod.Queue,
-        validation_policy: ValidationPolicy = None,
-        additional_properties: dict = None,
-        **kwargs
+        validation_policy: Optional[ValidationPolicy] = None,
+        additional_properties: Optional[dict] = None,
     ):
 
-        # backward compat - will be removed in future versions
-        dataFormat = kwargs.get("dataFormat", None)
-        ingestionMapping = kwargs.get("ingestionMapping", None)
-        ingestionMappingType = kwargs.get("ingestionMappingType", None)
-        ingestionMappingReference = kwargs.get("ingestionMappingReference", None)
-        additionalTags = kwargs.get("additionalTags", None)
-        ingestIfNotExists = kwargs.get("ingestIfNotExists", None)
-        ingestByTags = kwargs.get("ingestByTags", None)
-        dropByTags = kwargs.get("dropByTags", None)
-        flushImmediately = kwargs.get("flushImmediately", None)
-        reportLevel = kwargs.get("reportLevel", None)
-        reportMethod = kwargs.get("reportMethod", None)
-        validationPolicy = kwargs.get("validationPolicy", None)
-        additionalProperties = kwargs.get("additionalProperties", None)
+        if ingestion_mapping_reference is None and column_mappings is None:
+            if data_format._mapping_required:
+                raise KustoMissingMappingError(f"When stream format is '{data_format.kusto_value}', a mapping must be provided.")
+            if ingestion_mapping_kind is not None:
+                raise KustoMissingMappingError(f"When ingestion mapping kind is set ('{ingestion_mapping_kind.value}'), a mapping must be provided.")
+        else:  # A mapping is provided
+            if ingestion_mapping_kind is not None:
+                if data_format.ingestion_mapping_kind != ingestion_mapping_kind:
+                    raise KustoMappingError(
+                        f"Wrong ingestion mapping for format '{data_format.kusto_value}'; mapping kind should be '{data_format.ingestion_mapping_kind.value}', "
+                        f"but was '{ingestion_mapping_kind.value}'. "
+                    )
+            else:
+                ingestion_mapping_kind = data_format.ingestion_mapping_kind
 
-        mapping_exists = ingestionMapping is not None or ingestion_mapping is not None
-        if mapping_exists and (ingestion_mapping_reference is not None or ingestionMappingReference is not None):
-            raise KustoMappingAndMappingReferenceError()
+            if column_mappings is not None:
+                if ingestion_mapping_reference is not None:
+                    raise KustoDuplicateMappingError()
 
-        if ingestion_mapping_reference is not None and ingestionMappingReference is not None:
-            raise KustoDuplicateMappingReferenceError()
+                validation_errors = [
+                    f"Column mapping '{mapping.column}' is invalid." for mapping in column_mappings if not mapping.is_valid(ingestion_mapping_kind)
+                ]
+
+                if validation_errors:
+                    errors = "\n".join(validation_errors)
+                    raise KustoMappingError(f"Failed with validation errors:\n{errors}")
 
         self.database = database
         self.table = table
-        self.format = dataFormat or data_format
-        self.ingestion_mapping = ingestionMapping or ingestion_mapping
-        self.ingestion_mapping_type = ingestionMappingType or ingestion_mapping_type
-        self.ingestion_mapping_reference = ingestionMappingReference or ingestion_mapping_reference
-        self.additional_tags = additionalTags or additional_tags
-        self.ingest_if_not_exists = ingestIfNotExists or ingest_if_not_exists
-        self.ingest_by_tags = ingestByTags or ingest_by_tags
-        self.drop_by_tags = dropByTags or drop_by_tags
-        self.flush_immediately = flushImmediately or flush_immediately
-        self.report_level = reportLevel or report_level
-        self.report_method = reportMethod or report_method
-        self.validation_policy = validationPolicy or validation_policy
-        self.additional_properties = additionalProperties or additional_properties
+        self.format = data_format
+        self.ingestion_mapping = column_mappings
+        self.ingestion_mapping_type = ingestion_mapping_kind
+        self.ingestion_mapping_reference = ingestion_mapping_reference
+        self.additional_tags = additional_tags
+        self.ingest_if_not_exists = ingest_if_not_exists
+        self.ingest_by_tags = ingest_by_tags
+        self.drop_by_tags = drop_by_tags
+        self.flush_immediately = flush_immediately
+        self.report_level = report_level
+        self.report_method = report_method
+        self.validation_policy = validation_policy
+        self.additional_properties = additional_properties
