@@ -3,6 +3,7 @@
 
 import re
 from os import path
+
 from setuptools import setup, find_packages
 
 PACKAGE_NAME = "azure-kusto-ingest"
@@ -33,13 +34,13 @@ setup(
         # 5 - Production/Stable depends on multi-threading / aio / perf
         "Development Status :: 4 - Beta",
         "Programming Language :: Python",
-        "Programming Language :: Python :: 3.5",
-        "Programming Language :: Python :: 3.6",
         "Programming Language :: Python :: 3.7",
         "Programming Language :: Python :: 3.8",
+        "Programming Language :: Python :: 3.9",
+        "Programming Language :: Python :: 3.10",
         "License :: OSI Approved :: MIT License",
     ],
     packages=find_packages(exclude=["azure", "tests"]),
     install_requires=["azure-kusto-data=={}".format(VERSION), "azure-storage-blob>=12,<13", "azure-storage-queue>=12,<13"],
-    extras_require={"pandas": ["pandas"]},
+    extras_require={"pandas": ["pandas"], "aio": []},
 )
